<?php

function decodeAsciiHex($input) {
    $output = "";

    $isOdd = true;
    $isComment = false;

    for($i = 0, $codeHigh = -1; $i < strlen($input) && $input[$i] != '>'; $i++) {
        $c = $input[$i];

        if($isComment) {
            if ($c == '\r' || $c == '\n')
                $isComment = false;
            continue;
        }

        switch($c) {
            case '\0': case '\t': case '\r': case '\f': case '\n': case ' ': break;
            case '%':
                $isComment = true;
                break;

            default:
                $code = hexdec($c);
                if($code === 0 && $c != '0')
                    return "";

                if($isOdd)
                    $codeHigh = $code;
                else
                    $output .= chr($codeHigh * 16 + $code);

                $isOdd = !$isOdd;
                break;
        }
    }

    if($input[$i] != '>')
        return "";

    if($isOdd)
        $output .= chr($codeHigh * 16);

    return $output;
}
function decodeAscii85($input) {
    $output = "";

    $isComment = false;
    $ords = array();

    for($i = 0, $state = 0; $i < strlen($input) && $input[$i] != '~'; $i++) {
        $c = $input[$i];

        if($isComment) {
            if ($c == '\r' || $c == '\n')
                $isComment = false;
            continue;
        }

        if ($c == '\0' || $c == '\t' || $c == '\r' || $c == '\f' || $c == '\n' || $c == ' ')
            continue;
        if ($c == '%') {
            $isComment = true;
            continue;
        }
        if ($c == 'z' && $state === 0) {
            $output .= str_repeat(chr(0), 4);
            continue;
        }
        if ($c < '!' || $c > 'u')
            return "";

        $code = ord($input[$i]) & 0xff;
        $ords[$state++] = $code - ord('!');

        if ($state == 5) {
            $state = 0;
            for ($sum = 0, $j = 0; $j < 5; $j++)
                $sum = $sum * 85 + $ords[$j];
            for ($j = 3; $j >= 0; $j--)
                $output .= chr($sum >> ($j * 8));
        }
    }
    if ($state === 1)
        return "";
    elseif ($state > 1) {
        for ($i = 0, $sum = 0; $i < $state; $i++)
            $sum += ($ords[$i] + ($i == $state - 1)) * pow(85, 4 - $i);
        for ($i = 0; $i < $state - 1; $i++)
            $ouput .= chr($sum >> ((3 - $i) * 8));
    }

    return $output;
}
function decodeFlate($input) {
    return @gzuncompress($input);
}

function getObjectOptions($object) {
    $options = array();
    if (preg_match("#<<(.*)>>#ismU", $object, $options)) {
        $options = explode("/", $options[1]);
        @array_shift($options);

        $o = array();
        for ($j = 0; $j < @count($options); $j++) {
            $options[$j] = preg_replace("#\s+#", " ", trim($options[$j]));
            if (strpos($options[$j], " ") !== false) {
                $parts = explode(" ", $options[$j]);
                $o[$parts[0]] = $parts[1];
            } else
                $o[$options[$j]] = true;
        }
        $options = $o;
        unset($o);
    }

    return $options;
}
function getDecodedStream($stream, $options) {
    $data = "";
    if (empty($options["Filter"]))
        $data = $stream;
    else {
        $length = !empty($options["Length"]) ? $options["Length"] : strlen($stream);
        $_stream = substr($stream, 0, $length);

        foreach ($options as $key => $value) {
            if ($key == "ASCIIHexDecode")
                $_stream = decodeAsciiHex($_stream);
            if ($key == "ASCII85Decode")
                $_stream = decodeAscii85($_stream);
            if ($key == "FlateDecode")
                $_stream = decodeFlate($_stream);
        }
        $data = $_stream;
    }
    return $data;
}
function getDirtyTexts(&$texts, $textContainers) {
    for ($j = 0; $j < count($textContainers); $j++) {
        if (preg_match_all("#\[(.*)\]\s*TJ#ismU", $textContainers[$j], $parts))
            $texts = array_merge($texts, @$parts[1]);
        elseif(preg_match_all("#Td\s*(\(.*\))\s*Tj#ismU", $textContainers[$j], $parts))
            $texts = array_merge($texts, @$parts[1]);
    }
}
function getCharTransformations(&$transformations, $stream) {
    preg_match_all("#([0-9]+)\s+beginbfchar(.*)endbfchar#ismU", $stream, $chars, PREG_SET_ORDER);
    preg_match_all("#([0-9]+)\s+beginbfrange(.*)endbfrange#ismU", $stream, $ranges, PREG_SET_ORDER);

    for ($j = 0; $j < count($chars); $j++) {
        $count = $chars[$j][1];
        $current = explode("\n", trim($chars[$j][2]));
        for ($k = 0; $k < $count && $k < count($current); $k++) {
            if (preg_match("#<([0-9a-f]{2,4})>\s+<([0-9a-f]{4,512})>#is", trim($current[$k]), $map))
                $transformations[str_pad($map[1], 4, "0")] = $map[2];
        }
    }
    for ($j = 0; $j < count($ranges); $j++) {
        $count = $ranges[$j][1];
        $current = explode("\n", trim($ranges[$j][2]));
        for ($k = 0; $k < $count && $k < count($current); $k++) {
            if (preg_match("#<([0-9a-f]{4})>\s+<([0-9a-f]{4})>\s+<([0-9a-f]{4})>#is", trim($current[$k]), $map)) {
                $from = hexdec($map[1]);
                $to = hexdec($map[2]);
                $_from = hexdec($map[3]);

                for ($m = $from, $n = 0; $m <= $to; $m++, $n++)
                    $transformations[sprintf("%04X", $m)] = sprintf("%04X", $_from + $n);
            } elseif (preg_match("#<([0-9a-f]{4})>\s+<([0-9a-f]{4})>\s+\[(.*)\]#ismU", trim($current[$k]), $map)) {
                $from = hexdec($map[1]);
                $to = hexdec($map[2]);
                $parts = preg_split("#\s+#", trim($map[3]));

                for ($m = $from, $n = 0; $m <= $to && $n < count($parts); $m++, $n++)
                    $transformations[sprintf("%04X", $m)] = sprintf("%04X", hexdec($parts[$n]));
            }
        }
    }
}
function getTextUsingTransformations($texts, $transformations) {
    $document = "";
    for ($i = 0; $i < count($texts); $i++) {
        $isHex = false;
        $isPlain = false;

        $hex = "";
        $plain = "";
        for ($j = 0; $j < strlen($texts[$i]); $j++) {
            $c = $texts[$i][$j];
            switch($c) {
                case "<":
                    $hex = "";
                    $isHex = true;
                    break;
                case ">":
                    $hexs = str_split($hex, 4);
                    for ($k = 0; $k < count($hexs); $k++) {
                        $chex = str_pad($hexs[$k], 4, "0");
                        if (isset($transformations[$chex]))
                            $chex = $transformations[$chex];
                        //$document .= html_entity_decode("&#x".$chex.";");
                        $document .= $chex;
                    }
                    $isHex = false;
                    break;
                case "(":
                    $plain = "";
                    $isPlain = true;
                    break;
                case ")":
                    $document .= $plain;
                    $isPlain = false;
                    break;
                case "\\":
                    $c2 = $texts[$i][$j + 1];
                    if (in_array($c2, array("\\", "(", ")"))) $plain .= $c2;
                    elseif ($c2 == "n") $plain .= '\n';
                    elseif ($c2 == "r") $plain .= '\r';
                    elseif ($c2 == "t") $plain .= '\t';
                    elseif ($c2 == "b") $plain .= '\b';
                    elseif ($c2 == "f") $plain .= '\f';
                    elseif ($c2 >= '0' && $c2 <= '9') {
                        $oct = preg_replace("#[^0-9]#", "", substr($texts[$i], $j + 1, 3));
                        $j += strlen($oct) - 1;
                       // $plain .= html_entity_decode("&#".octdec($oct).";");
                        $plain .= $oct;
                    }
                    $j++;
                    break;

                default:
                    if ($isHex)
                        $hex .= $c;
                    if ($isPlain)
                        $plain .= $c;
                    break;
            }
        }
        $document .= "<br/>";
    }

    return $document;
}

function pdf2text($filename) {
    $infile = @file_get_contents($filename, FILE_BINARY);

    if (empty($infile))
        return "";

    $transformations = array();
    $texts = array();

    preg_match_all("#obj(.*)endobj#ismU", $infile, $objects);
    $objects = @$objects[1];

    for ($i = 0; $i < count($objects); $i++) {
        $currentObject = $objects[$i];

        if (preg_match("#stream(.*)endstream#ismU", $currentObject, $stream)) {
            $stream = ltrim($stream[1]);

            $options = getObjectOptions($currentObject);
            /*if (!(empty($options["Length1"]) && empty($options["Type"]) && empty($options["Subtype"])))
                continue;*/

            $data = getDecodedStream($stream, $options);


            if (strlen($data)) {
                //if (preg_match_all("#BT(.*)ET#ismU", $data, $textContainers)) {
                if (preg_match_all("#BT(.*)ET#", $data, $textContainers)) {
                    $textContainers = @$textContainers[1];

                    getDirtyTexts($texts, $textContainers);
                } else {

                    //getCharTransformations($transformations, $data);
                }
            }
        }
    }

    return getTextUsingTransformations($texts, $transformations);
}

function get_article_contents($keyword, $page_num = 1) {

    $query = 'http://api.ezinearticles.com/api.php?search=articles&q=' . urlencode($keyword) . '&page='.$page_num.'&limit=1&response_format=json&key=6vJFPnrGdKlblyFIVoGQAhSaixbT2V';
    $json_content = json_decode(file_get_contents($query));

    if(!isset($json_content->{'error'})) {
        $article_url = $json_content->{'articles'}[0]->{'article'}->{'url'};
        $article_id = $json_content->{'articles'}[0]->{'article'}->{'id'};
        $article_author = $json_content->{'articles'}[0]->{'article'}->{'author'};
        $article_date_published = $json_content->{'articles'}[0]->{'article'}->{'date_published'};
        $article_last_updated = $json_content->{'articles'}[0]->{'article'}->{'date_updated'};
        $article_title = $json_content->{'articles'}[0]->{'article'}->{'title'};
        $article_category = $json_content->{'articles'}[0]->{'article'}->{'category'};
        $article_summary = $json_content->{'articles'}[0]->{'article'}->{'summary'};
        $article_content = pdf2text("http://www.ezinearticles.com/article/print/" . $article_id);
        $article_content = str_replace($article_author, ' ', $article_content);
        $article_content = str_replace('Written by', ' ', $article_content);
        $article_content = str_replace('Article Source: http://EzineArticles.com/' . $article_id, '', $article_content);
        $article_content = str_replace($article_date_published, '', $article_content);
        $article_content = base64_encode($article_content);
        $result = array(
            'article_url' => $article_url,
            'article_id' => $article_id,
            'article_author' => $article_author,
            'article_date_published' => $article_date_published,
            'article_last_updated' => $article_last_updated,
            'article_title' => $article_title,
            'article_category' => $article_category,
            'article_summary' => $article_summary,
            'article_content' => $article_content
        );
    } else {
        $result = null;
    }
    return $result;
}

/**
 * @param $keyword
 * @param int $page_num
 * Description: get article content from ezinemark.com
 */

function get_article_ezinemark($keyword, $page_num = 1) {
    $real_page_num = ((int)$page_num / 15) + 1;
    // get article url
    $blist[] = "Mozilla/5.0 (compatible; Konqueror/4.0; Microsoft Windows) KHTML/4.0.80 (like Gecko)";
    $blist[] = "Mozilla/5.0 (compatible; Konqueror/3.92; Microsoft Windows) KHTML/3.92.0 (like Gecko)";
    $blist[] = "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506; Media Center PC 5.0; .NET CLR 1.1.4322; Windows-Media-Player/10.00.00.3990; InfoPath.2";
    $blist[] = "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727; .NET CLR 3.0.04506.30; Dealio Deskball 3.0)";
    $blist[] = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; NeosBrowser; .NET CLR 1.1.4322; .NET CLR 2.0.50727)";
    $ua = $blist[array_rand($blist)];
    if ( function_exists('curl_init') ) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_USERAGENT, $ua);
        curl_setopt($ch, CURLOPT_URL,'http://ezinemark.com/a/'. urlencode($keyword) .'/p-' . $real_page_num . '/');
        curl_setopt($ch, CURLOPT_FAILONERROR, true);
        curl_setopt($ch, CURLOPT_AUTOREFERER, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER,true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 45);
        $search_html = curl_exec($ch);
        curl_close($ch);
        if (!$search_html) {
            $result = array(
                'error' => 'no article',
                'message' => 'Not found any article'
            );
            return $result;
        }

    } else {
        $search_html = @file_get_contents('http://ezinemark.com/a/'. urlencode($keyword) .'/p-' . $real_page_num . '/');
        if (!$search_html) {
            $result = array(
                'error' => 'no article',
                'message' => 'Not found any article'
            );
            return $result;
        }
    }


    $dom = new DOMDocument();
    @$dom->loadHTML($search_html);
    $xpath = new DOMXPath($dom);
    $paras = $xpath->query("//div[@class='l_search']//h3/a");
    if($paras->length == 0) {
        $result = array(
            'error' => 'no article',
            'message' => 'Not found any article'
        );
        return $result;
    }
    $url_index = (int)$page_num % 15 - 1;
    $target_url = $paras->item($url_index)->getAttribute('href');

    // get article title
    if ( function_exists('curl_init') ) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_USERAGENT, $ua);
        curl_setopt($ch, CURLOPT_URL,$target_url);
        curl_setopt($ch, CURLOPT_FAILONERROR, true);
        curl_setopt($ch, CURLOPT_AUTOREFERER, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER,true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 45);
        $article_html = curl_exec($ch);
        curl_close($ch);
        if (!$article_html) {
            $result = array(
                'error' => 'no article',
                'message' => 'Not found any article'
            );
            return $result;
        }
    } else {
        $article_html = @file_get_contents($target_url);
        if (!$article_html) {
            $result = array(
                'error' => 'no article',
                'message' => 'Not found any article'
            );
            return $result;
        }
    }


    $dom = new DOMDocument();
    @$dom->loadHTML($article_html);
    $xpath_title = new DOMXPath($dom);
    $title_object = $xpath_title->query("//div[@class='d_ctitle']/h1");

    $title = $title_object->item(0)->textContent;
    if(empty($title)) {
        $result = array(
            'error' => 'no article',
            'message' => 'Not found any article'
        );
        return $result;
    }
    // get article content
    $xpath_content = new DOMXPath($dom);
    $content_object = $xpath_content->query("//div[@id='art_content']");
    $content = $dom->saveXML($content_object->item(0));
    if(empty($content)) {
        $result = array(
            'error' => 'no article',
            'message' => 'Not found any article'
        );
        return $result;
    }
    $content = str_replace('<div class="KonaBody">', "", $content);
    $content = str_replace("]]>", "", $content);
    $content = str_replace("]]&gt;", "", $content);
    $content = str_replace("&nbsp;", "", $content);
    $content = preg_replace('#<div class="related_links">(.*)</ul></div>#smiU', '', $content);
    $content = strip_tags($content,'<p><strong><b><a><br>');
    $content = str_replace("</div>", "", $content);
    $content = str_replace("$", "$ ", $content);
    $content = str_replace("<div>", "", $content);

    // get article author info
    $xpath_author = new DOMXPath($dom);
    $author_object = $xpath_author->query("//div[@class='authorbox']/div[@class='rightbl']//p");
    $author_info = "About the Author: <div>";
    for($i = 0; $i < $author_object->length; $i ++ ) {
        $param = $author_object->item($i);
        $author_info .= $dom->saveXML($param);
    }
    $author_info .= "</div>";
    $author_info .= 'Articles Source: <a href="' . $target_url . '" target="_blank">' . $title . '</a>';

    // get article author name
    $xpath_author_name = new DOMXPath($dom);
    $author_name_object = $xpath_author_name->query("//div[@class='authorbox']/div[@class='rightbl']/a");
    $param = $author_name_object->item(0);
    $author_name = $dom->saveXML($param);
    //$content .= $author_info;

    $result = array(
        'article_url' => $target_url,
        'article_title' => $title,
        'article_content' => base64_encode($content),
        'article_author' => base64_encode($author_info),
        'article_author_name' => base64_encode($author_name)
    );

    return $result;

}
function get_youtube_contents($keyword, $page_num) {
    $query = 'http://gdata.youtube.com/feeds/api/videos?vq=' . urlencode($keyword) . '&orderby=viewCount&max-results=1&start-index=' . $page_num . '&alt=json';
    $json_content = json_decode(file_get_contents($query), true);

    if(isset($json_content['feed']['entry'])) {
        $url = $json_content['feed']['entry'][0]['link'][0]['href'];
        $parts = parse_url($url);
        parse_str($parts['query'], $params);
        $youtube_id = $params['v'];
        $viewCount = $json_content['feed']['entry'][0]['yt$statistics']['viewCount'];
        $title = $json_content['feed']['entry'][0]['title']['$t'];

        $result = array(
            'youtube_id' => $youtube_id,
            'youtube_url' => $url,
            'youtube_view_count' => $viewCount,
            'youtube_title' => $title
        );

    } else {
        $result = null;
    }

    return $result;
}

function get_flickr_contents($keyword, $page_num) {

    $query = 'http://www.flickr.com/services/rest/?method=flickr.photos.search&sort=relevance&api_key=29aff4dfd9b71ee4299c379a24207c62&text='. urlencode($keyword).'&per_page=10&format=php_serial&per_page=1&page='.$page_num;
    $json_content = unserialize(file_get_contents($query));
    if(isset($json_content['photos']['photo']) && is_array($json_content['photos']['photo'])) {
        $imag_src = 'http://farm' . $json_content['photos']['photo'][0]['farm'] . '.static.flickr.com/'. $json_content['photos']['photo'][0]["server"] . '/' . $json_content['photos']['photo'][0]["id"] . '_' . $json_content['photos']['photo'][0]["secret"] . '.jpg';
        list( $width, $height ) = getimagesize( $imag_src );
        $result = array(
            'flickr_title' => $json_content['photos']['photo'][0]['title'],
            'flickr_img_src' => $imag_src,
            'width' => $width,
            'height' => $height
        );
    } else {
        $result = null;
    }

    return $result;
}

// ------------------ Shortcode -----------------------------------

add_shortcode('ar-ezinearticle', 'arf_ezinearticle_shortcode');

function arf_ezinearticle_shortcode($atts) {
    global $wpdb;
    extract(shortcode_atts(array(
        'id' => ''
    ), $atts));

    if($id == '')
        return '';
    $query = 'select * from ' . AUTHORITY_ROBOT_TABLE .' ';
    $query .= 'where id=' . $id ;

    $items = $wpdb->get_results(  $query , ARRAY_A );
    return base64_decode($items[0]['content']);

}

add_shortcode('ar-youtube', 'arf_youtube_shortcode');

function arf_youtube_shortcode($atts) {
    extract(shortcode_atts(array(
        'id' => '',
        'width' => '400',
        'height' => '310'
    ), $atts));

    if($id == '' || intval($width) < 1 || intval($height) < 1)
        return '';

    $output = '<iframe width="' . $width . '" height="' . $height . '" src="http://www.youtube.com/embed/' . $id . '" frameborder="0" allowfullscreen></iframe>';

    return $output;

}

add_shortcode('ar-flickr-image', 'arf_flickr_shortcode');

function arf_flickr_shortcode($atts) {
    extract(shortcode_atts(array(
        'src' => '',
        'width' => '0',
        'height' => '0'
    ), $atts));

    if($src == '' || intval($width) <= 0 || intval($height) <= 0)
        return '';

    $output = '<img src="'. base64_decode($src) . '" width="' .$width.'" height="' . $height . '" />';
    return $output;
}


function ara_wp_image_editor( $msg = false) {
    $nonce = wp_create_nonce("image_editor-111");
    $note = '';

    if ( $msg ) {
        if ( isset($msg->error) )
            $note = "<div class='error'><p>$msg->error</p></div>";
        elseif ( isset($msg->msg) )
            $note = "<div class='updated'><p>$msg->msg</p></div>";
    }

    ?>
    <div class="imgedit-wrap-1111">
        <?php echo $note; ?>
        <table id="imgedit-panel-111"><tbody>
            <tr><td>
                    <div class="imgedit-menu">
                        <div onclick="imageEdit.crop(<?php echo "111, '$nonce'"; ?>, this)" class="imgedit-crop disabled" title="<?php esc_attr_e( 'Crop' ); ?>"></div><?php

                        // On some setups GD library does not provide imagerotate() - Ticket #11536
                        if ( wp_image_editor_supports( array( 'mime_type' => 'image/jpeg', 'methods' => array( 'rotate' ) ) ) ) { ?>
                            <div class="imgedit-rleft"  onclick="imageEdit.rotate( 90, <?php echo "111, '$nonce'"; ?>, this)" title="<?php esc_attr_e( 'Rotate counter-clockwise' ); ?>"></div>
                            <div class="imgedit-rright" onclick="imageEdit.rotate(-90, <?php echo "111, '$nonce'"; ?>, this)" title="<?php esc_attr_e( 'Rotate clockwise' ); ?>"></div>
                        <?php } else {
                            $note_no_rotate = esc_attr__('Image rotation is not supported by your web host.');
                            ?>
                            <div class="imgedit-rleft disabled"  title="<?php echo $note_no_rotate; ?>"></div>
                            <div class="imgedit-rright disabled" title="<?php echo $note_no_rotate; ?>"></div>
                        <?php } ?>

                        <div onclick="imageEdit.flip(1, <?php echo "111, '$nonce'"; ?>, this)" class="imgedit-flipv" title="<?php esc_attr_e( 'Flip vertically' ); ?>"></div>
                        <div onclick="imageEdit.flip(2, <?php echo "111, '$nonce'"; ?>, this)" class="imgedit-fliph" title="<?php esc_attr_e( 'Flip horizontally' ); ?>"></div>

                        <div id="image-undo-<?php echo 111; ?>" onclick="imageEdit.undo(<?php echo "111, '$nonce'"; ?>, this)" class="imgedit-undo disabled" title="<?php esc_attr_e( 'Undo' ); ?>"></div>
                        <div id="image-redo-<?php echo 111; ?>" onclick="imageEdit.redo(<?php echo "111, '$nonce'"; ?>, this)" class="imgedit-redo disabled" title="<?php esc_attr_e( 'Redo' ); ?>"></div>
                        <br class="clear" />
                    </div>

                    <input type="hidden" id="imgedit-sizer-111" value="" />
                    <input type="hidden" id="imgedit-minthumb-111" value="<?php echo ( get_option('thumbnail_size_w') . ':' . get_option('thumbnail_size_h') ); ?>" />
                    <input type="hidden" id="imgedit-history-111" value="" />
                    <input type="hidden" id="imgedit-undone-111" value="0" />
                    <input type="hidden" id="imgedit-selection-111" value="" />
                    <input type="hidden" id="imgedit-x-111" value="0" />
                    <input type="hidden" id="imgedit-y-111" value="0" />

                    <div id="imgedit-crop-111" class="imgedit-crop-wrap">
                        <img id="image-preview-111" onload="imageEdit.imgLoaded('111')" src="<?php echo AUTHORITY_ROBOT_URL; ?>images/screenshot-1.png" />
                    </div>

                </td>

                <td class="imgedit-settings">
                    <div class="imgedit-group">
                        <div class="imgedit-group-top">
                            <strong><?php _e('Image Crop'); ?></strong>
                            <a class="imgedit-help-toggle" onclick="imageEdit.toggleHelp(this);return false;" href="#"><?php _e('(help)'); ?></a>
                            <div class="imgedit-help">
                                <p><?php _e('The image can be cropped by clicking on it and dragging to select the desired part. While dragging the dimensions of the selection are displayed below.'); ?></p>

                                <p><strong><?php _e('Crop Aspect Ratio'); ?></strong><br />
                                    <?php _e('You can specify the crop selection aspect ratio then hold down the Shift key while dragging to lock it. The values can be 1:1 (square), 4:3, 16:9, etc. If there is a selection, specifying aspect ratio will set it immediately.'); ?></p>

                                <p><strong><?php _e('Crop Selection'); ?></strong><br />
                                    <?php _e('Once started, the selection can be adjusted by entering new values (in pixels). Note that these values are scaled to approximately match the original image dimensions. The minimum selection size equals the thumbnail size as set in the Media settings.'); ?></p>
                            </div>
                        </div>

                        <p>
                            <?php _e('Aspect ratio:'); ?>
                            <span  class="nowrap">
		<input type="text" id="imgedit-crop-width-<?php echo 111; ?>" onkeyup="imageEdit.setRatioSelection(<?php echo 111; ?>, 0, this)" style="width:3em;" />
		:
		<input type="text" id="imgedit-crop-height-<?php echo 111; ?>" onkeyup="imageEdit.setRatioSelection(<?php echo 111; ?>, 1, this)" style="width:3em;" />
		</span>
                        </p>

                        <p id="imgedit-crop-sel-<?php echo 111; ?>">
                            <?php _e('Selection:'); ?>
                            <span  class="nowrap">
		<input type="text" id="imgedit-sel-width-<?php echo 111; ?>" onkeyup="imageEdit.setNumSelection(<?php echo 111; ?>)" style="width:4em;" />
		:
		<input type="text" id="imgedit-sel-height-<?php echo 111; ?>" onkeyup="imageEdit.setNumSelection(<?php echo 111; ?>)" style="width:4em;" />
		</span>
                        </p>
                    </div>



                </td></tr>
            </tbody></table>
        <div class="imgedit-wait" id="imgedit-wait-<?php echo 111; ?>"></div>
        <script type="text/javascript">$( function() { imageEdit.init(<?php echo 111; ?>); });</script>
        <div class="hidden" id="imgedit-leaving-<?php echo 111; ?>"><?php _e("There are unsaved changes that will be lost. 'OK' to continue, 'Cancel' to return to the Image Editor."); ?></div>
    </div>
<?php
}
